/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.httpclient;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.HttpURLConnection;

import org.zhiqim.kernel.util.Streams;

/**
 * HTTP/HTTPS 流客户端
 *
 * @version v1.0.0 @author zouzhigang 2018-8-3 新建与整理
 */
public class HttpStream extends HttpClient
{
    private ByteArrayOutputStream out;
    private ByteArrayOutputStream in;
    
    public HttpStream(String url, String method)
    {
        super(url, method);
        this.out = new ByteArrayOutputStream();
    }
    
    /********************************************************************************/
    //输出到服务端
    /********************************************************************************/

    /** 获取输出流 */
    public OutputStream getOutputStream()
    {
        return out;
    }
    
    /** 输出字节 */
    public void write(int b)
    {
        out.write(b);
    }
    
    /** 输出字节数组 */
    public void write(byte[] b)
    {
        out.write(b, 0, b.length);
    }
    
    /** 输出字节数组偏移量 */
    public void write(byte[] b, int off, int len)
    {
        out.write(b, off, len);
    }
    
    /********************************************************************************/
    //输入到客户端
    /********************************************************************************/

    /** 重写获取HTTP结果 */
    public HttpResult getResult()
    {
        return new HttpResult(responseStatus, responseText, in==null?null:in.toByteArray());
    }
    
    /** 获取输入流 */
    public InputStream getInputStream()
    {
        return new ByteArrayInputStream(in.toByteArray());
    }
    
    /** 获取字节数组 */
    public byte[] getBytes()
    {
        return in.toByteArray();
    }
    
    /********************************************************************************/
    //实现HTTP抽象方法
    /********************************************************************************/

    protected boolean doPreRequestProperty()
    {
        setDoOutput(true);
        return true;
    }
    
    protected void doWriteRequestContent(HttpURLConnection conn) throws IOException
    {
        out.writeTo(conn.getOutputStream());
    }
    
    protected void doReadResponseContent(HttpURLConnection conn) throws IOException
    {
        if (responseStatus == _302_FOUND_)
        {//重定向
            responseText = conn.getHeaderField("Location");
            return;
        }
        
        if (responseStatus != _200_OK_)
        {//错误
            responseText = getResponseError(conn);
            return;
        }
        
        //成功
        in = new ByteArrayOutputStream();
        try(InputStream input = conn.getInputStream())
        {
            Streams.putBytes(input, in);
        }
        
        responseText = "调用成功";
    }
}