/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.paging;

import org.zhiqim.kernel.annotation.AnAlias;
import org.zhiqim.kernel.annotation.AnGlobal;
import org.zhiqim.kernel.constants.SignConstants;
import org.zhiqim.kernel.util.Validates;

/**
 * 标准分页显示，使用按钮实现，支持显示如下：<br>
 * 1、总条数<br>
 * 2、首页<br>
 * 3、上一页<br>
 * 4、显示每5页，如（1－5，6－10）<br>
 * 5、下一页<br>
 * 6、末页<br>
 *
 * @version v1.0.0 @author zouzhigang 2016-9-3 新建与整理
 * @version v1.0.1 @author zouzhigang 2017-11-16 修改为实现Paging接口，采用@AnGlobal
 */
@AnAlias("PagingGo")
@AnGlobal
public class PagingGo implements Paging, SignConstants
{
    /**
     * 提供传入的是URL链接的分页显示
     * 
     * @param result        结果集
     * @return              分页显示HTML
     */
    public String toHtmlLink(PageResult<?> result)
    {
        return toHtmlLink(result, null);
    }
    
    /**
     * 提供传入的是URL链接的分页显示
     * 
     * @param result        结果集
     * @param link          URL链接
     * @return              分页显示HTML
     */
    public String toHtmlLink(PageResult<?> result, String link)
    {
        if (result == null)
            result = PageBuilder.newResult(20);
        
        if (link == null)
            link = _EMPTY_;
        
        String condition = result.getConditionUrl();
        if (Validates.isNotEmpty(condition))
            link += condition + "&";
        else
           link += "?";
        
        StringBuilder strb = new StringBuilder();
        strb.append("<div class=\"z-relative-center z-text-center\">");
        
        strb.append("<span class=\"z-float-left z-button z-mg-r5 z-readonly\">总&nbsp;<span class=\"z-bold z-text-red\">").append(result.total()).append("</span>&nbsp;条</span>");
        
        if (result.hasFirst())
            strb.append("<span class=\"z-float-left z-button z-mg-r3\" onclick=\"location.href='" + link + "page=1'\">首页</span>");
        else
            strb.append("<span class=\"z-float-left z-button z-mg-r3 z-readonly\">首页</span>");
    
        if (result.hasPrevious())
            strb.append("<span class=\"z-float-left z-button z-mg-r3\" onclick=\"location.href='" + link + "page=" + (result.pageNo() - 1) + "'\">上一页</span>");
        else
            strb.append("<span class=\"z-float-left z-button z-mg-r3 z-readonly\">上一页</span>");
    
        int lBound = result.getLSegmentNo(5);
        int rBound = result.getRSegmentNo(5);
        
        if (result.hasLSegment(5))
            strb.append("<span class=\"z-float-left z-button z-mg-r3\" onclick=\"location.href='"+link+"page="+(lBound - 1)+"'\"><<</span>");
            
        for (int i=lBound; i<rBound; i++)
        {
            if (result.pageNo() != i)
                strb.append("<span class=\"z-float-left z-button z-mg-r3\" onclick=\"location.href='"+link+"page="+ i +"'\">"+i+"</span>");
            else
                strb.append("<span class=\"z-float-left z-button z-mg-r3 z-red\" onclick=\"location.href='"+link+"page="+ i +"'\">"+i+"</span>");
        }
        
        if (result.hasRSegment(5))
            strb.append("<span class=\"z-float-left z-button z-mg-r3\" onclick=\"location.href='"+link+"page="+ rBound +"'\">>></span>");
   
        if (result.hasNext())
            strb.append("<span class=\"z-float-left z-button z-mg-r3\" onclick=\"location.href='" + link + "page=" + (result.pageNo() + 1) + "'\">下一页</span>");
        else
            strb.append("<span class=\"z-float-left z-button z-mg-r3 z-readonly\">下一页</span>");
    
        if (result.hasLast())
            strb.append("<span class=\"z-float-left z-button\" onclick=\"location.href='" + link + "page="+ result.totalPages() + "'\">末页</span>");
        else
            strb.append("<span class=\"z-float-left z-button z-readonly\">末页</span>");
        
        //新增GO
        strb.append("<input class=\"z-float-left z-input z-mg-l3 zi-bd-r-none zi-bd-rd-tl3 zi-bd-rd-bl3 zi-samp\" data-options=\"type:Integer;\" style=\"width:42px;border:1px solid #d2d2d2;color:#333;\">");
        strb.append("<span class=\"z-float-left z-button z-mg-r5 zi-pd-l5 zi-pd-r5 zi-bd-rd0 zi-bd-rd-tr3 zi-bd-rd-br3\" onclick=\"location.href='"+link+"page='+Z(this).siblings('input').val();\">GO</span>");
        
        strb.append("<span class=\"z-float-left z-button z-readonly\">").append(result.pageNo()).append("/").append(result.totalPages()).append("(").append(result.pageSize()).append(")").append("</span>");
        strb.append("</div>");
        return strb.toString();
    }
    
    /**
     * 提供传入的是Js函数名的分页显示
     * 
     * @param result        结果集
     * @param jsMethod      Js函数
     * @return              分页显示HTML
     */
    public String toHtmlClick(PageResult<?> result, String jsMethod)
    {
        return toHtmlClick(result, jsMethod, null, null);
    }
    
    /**
     * 提供传入的是Js函数名的分页显示
     * 
     * @param result        结果集
     * @param cls           类名
     * @param               方法
     * @return              分页显示HTML
     */
    public String toHtmlClick(PageResult<?> result, String cls, String method)
    {
        return toHtmlClick(result, null, cls, method);
    }
    
    /** 提供传入的是Js函数名或类和方法的分页显示 */
    private String toHtmlClick(PageResult<?> result, String jsMethod, String cls, String method)
    {
        if (result == null)
            result = PageBuilder.newResult(20);
        
        String click = (jsMethod == null)?("Z.ajaxq('" + cls + "', '" + method + "', "):(jsMethod + "(");
        
        StringBuilder strb = new StringBuilder();
        strb.append("<div class=\"z-relative-center z-text-center\">");
        
        strb.append("<span class=\"z-float-left z-button z-mg-r5 z-readonly\">总&nbsp;<span class=\"z-bold z-text-red\">").append(result.total()).append("</span>&nbsp;条</span>");
        
        if (result.hasFirst())
            strb.append("<span class=\"z-float-left z-button z-mg-r3\" onclick=\""+click + "1);\">首页</span>");
        else
            strb.append("<span class=\"z-float-left z-button z-mg-r3 z-readonly\">首页</span>");
    
        if (result.hasPrevious())
            strb.append("<span class=\"z-float-left z-button z-mg-r3\" onclick=\""+click + (result.pageNo() - 1) + ");\">上一页</span>");
        else
            strb.append("<span class=\"z-float-left z-button z-mg-r3 z-readonly\">上一页</span>");
    
        int lBound = result.getLSegmentNo(5);
        int rBound = result.getRSegmentNo(5);
        
        if (result.hasLSegment(5))
            strb.append("<span class=\"z-float-left z-button z-mg-r3\" onclick=\""+click + (lBound - 1)+");\">&lt;&lt;</span>");
            
        for (int i=lBound; i<rBound; i++)
        {
            strb.append("<span class=\"z-float-left z-button z-mg-r3");
            if (result.pageNo() == i)
                strb.append(" z-red");
            strb.append("\" onclick=\""+ click + i +");\">"+i+"</span>");
        }
        
        if (result.hasRSegment(5))
            strb.append("<span class=\"z-float-left z-button z-mg-r3\" onclick=\""+click + rBound +");\">&gt;&gt;</span>");
   
        if (result.hasNext())
            strb.append("<span class=\"z-float-left z-button z-mg-r3\" onclick=\""+click + (result.pageNo() + 1) + ");\">下一页</span>");
        else
            strb.append("<span class=\"z-float-left z-button z-mg-r3 z-readonly\">下一页</span>");
    
        if (result.hasLast())
            strb.append("<span class=\"z-float-left z-button\" onclick=\""+click + result.totalPages() + ");\">末页</span>");
        else
            strb.append("<span class=\"z-float-left z-button z-readonly\">末页</span>");
        
        //新增GO
        strb.append("<input class=\"z-float-left z-input z-mg-l3 zi-bd-r-none zi-bd-rd-tl3 zi-bd-rd-bl3 zi-samp\" data-options=\"type:Integer;\" style=\"width:42px;border:1px solid #d2d2d2;color:#333;\">");
        strb.append("<span class=\"z-float-left z-button zi-pd-l5 z-mg-r5 zi-pd-r5 zi-bd-rd0 zi-bd-rd-tr3 zi-bd-rd-br3\" onclick=\"" + click + "Z(this).siblings('input').val());\">GO</span>");
        
        strb.append("<span class=\"z-float-left z-button z-readonly\">").append(result.pageNo()).append("/").append(result.totalPages()).append("(").append(result.pageSize()).append(")").append("</span>");
        strb.append("</div>");
        return strb.toString();
    }
}
