/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.util.mutables;

/**
 * 定义布尔型可变对象，用于引用传递时直接修改值
 *
 * @version v1.0.0 @author zhichenggang 2017-3-25 新建与整理
 */
public final class MObj<T>
{
    public volatile T value;
    
    /*******************************************************/
    //两个构造函数
    /*******************************************************/
    
    public MObj()
    {
    }
    
    public MObj(T value)
    {
        this.value = value;
    }
    
    /*******************************************************/
    //常用方法
    /*******************************************************/
    
    public T val()
    {
        return value;
    }
    
    public MObj<T> val(T val)
    {
        this.value = val;
        return this;
    }
    
    public MObj<T> val(MObj<T> val)
    {
        this.value = val.value;
        return this;
    }
    
    /*******************************************************/
    //hashCode & equals & toString
    /*******************************************************/
    
    public int hashCode()
    {
        return value == null?0:value.hashCode();
    }

    public boolean equals(Object obj)
    {
        if (this == obj)
            return true;
        if (obj == null)
            return false;
        if (getClass() != obj.getClass())
            return false;
        
        @SuppressWarnings("rawtypes")
        MObj other = (MObj) obj;
        if (value == null)
            return other.value == null;
        else
            return value.equals(other.value);
    }

    public String toString()
    {
        return String.valueOf(value);
    }
}
