/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.util.streams;

import java.io.FilterOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.security.MessageDigest;

/**
 * 摘要输出流，写入流的同时，记录长度和更新摘要信息
 *
 * @version v1.0.0 @author zouzhigang 2016-12-12 新建与整理
 */
public class DigestOutputStream extends FilterOutputStream
{
    private MessageDigest digest;
    private long length;

    public DigestOutputStream(OutputStream stream, MessageDigest digest)
    {
        super(stream);
        this.digest = digest;
    }
    
    /**************************************************************************/
    //写入流，同时更新摘要和数目
    /**************************************************************************/

    public void write(int b) throws IOException
    {
        out.write(b);
        digest.update((byte) b);
        length++;
    }

    public void write(byte[] b, int off, int len) throws IOException
    {
        out.write(b, off, len);
        digest.update(b, off, len);
        length += len;
    }
    
    public void write(byte[] b) throws IOException
    {
        out.write(b);
        digest.update(b);
        length += b.length;
    }
    
    /**************************************************************************/
    //获取最终摘要和数目
    /**************************************************************************/

    public MessageDigest getMessageDigest()
    {
        return digest;
    }
    
    public byte[] digest()
    {
        return digest.digest();
    }
    
    public long length()
    {
        return length;
    }

    public String toString()
    {
        return "[DigestOutputStream] " + digest.toString();
    }
}