/*
 * 版权所有 (C) 2015 知启蒙(ZHIQIM) 保留所有权利。[遇见知启蒙，邂逅框架梦]
 * 
 * https://zhiqim.org/project/zhiqim_framework/zhiqim_kernel.htm
 *
 * Zhiqim Kernel is licensed under Mulan PSL v2.
 * You can use this software according to the terms and conditions of the Mulan PSL v2.
 * You may obtain a copy of Mulan PSL v2 at:
 *          http://license.coscl.org.cn/MulanPSL2
 * THIS SOFTWARE IS PROVIDED ON AN "AS IS" BASIS, WITHOUT WARRANTIES OF ANY KIND,
 * EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO NON-INFRINGEMENT,
 * MERCHANTABILITY OR FIT FOR A PARTICULAR PURPOSE.
 * See the Mulan PSL v2 for more details.
 */
package org.zhiqim.kernel.xml.parser;

import java.util.Map.Entry;

import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.zhiqim.kernel.extend.MapSS;
import org.zhiqim.kernel.util.Classes;
import org.zhiqim.kernel.util.Strings;
import org.zhiqim.kernel.xml.Xml;
import org.zhiqim.kernel.xml.XmlParser;
import org.zhiqim.kernel.xml.Xmls;

/**
 * MapSO解析器，和哈唏表解析器类似
 *
 * @version v1.1.2 @author zouzhigang 2015-8-21 新建与整理
 */
public class MapSSParser implements XmlParser
{
    private Xml xmlMain;
    
    @Override
    public XmlParser set(Xml xmlMain)
    {
        this.xmlMain = xmlMain;
        return this;
    }
    
    @Override
    public String toStringInner(Object obj, String tagName, int tagLevel)
    {
        MapSS map = (MapSS)obj;
        if (tagName == null)
            tagName = map.getXmlTag();
        
        StringBuilder strb = new StringBuilder();
        Strings.addNewLine(strb);
        Strings.addTwoSpace(strb, tagLevel);
        Xmls.addTagBegin(strb, tagName);
        
        for (Entry<String, String> entry : map.entrySet())
        {
            String tag = entry.getKey();
            String value = entry.getValue();
            strb.append(xmlMain.toStringInner(value, tag, tagLevel+1));
        }
        
        Strings.addNewLine(strb);
        Strings.addTwoSpace(strb, tagLevel);
        Xmls.addTagEnd(strb, tagName);
        return strb.toString();
    }

    @Override
    public Object toObjectInner(Node node, Class<?> clazz, Class<?> generics)
    {
        MapSS map = Classes.newMapSS(clazz);
        if (map == null)
        {//不支持的类型
            return null;
        }
        
        if (node == null)
        {//没有内容或没配置泛型返回空表
            return map;
        }
        
        map.setXmlTag(node.getNodeName());
        NodeList childList = node.getChildNodes();
        for (int i=0;i<childList.getLength();i++)
        {
            Node child = childList.item(i);
            if (child.getNodeType() != Node.ELEMENT_NODE)
                continue;
            
            String key = child.getNodeName();
            map.put(key, xmlMain.toObjectInner(child, String.class, null));
        }
        
        return map;
    }
}
